## Usage

It is recommended to run the project on a python virtual environment.

1) Install requirements.txt

### BRAT2DRS

1) Change directory to *brat2drs*
2) Run **brat2drs.py**
            
    * Creates drs representations, under *brat2viz/drs_files*, from the files under *brat_ann_files*. 

### DRS2VIZ

1) Change directory to *drs2viz*
2) Run npm init && npm install vis-network
4) Run **app.py**

    * Starts a flask server running the representations on http://localhost:5055/brat2viz

## Online Demo

https://nabu.dcc.fc.up.pt/brat2viz
